Config File
===========

   Manage and manipulate your configuration files

|Python Verison| |Version| |Style| |Documentation Status| |Build Status| |Codecov|

   This python package is currently in rapid development and is in a
   pre-alpha phase. The API is liable to break until v1 so if you're
   going to use it, pinning the version is recommended. All notable
   changes are kept track of in the changelog.

Config File allows you to use the same simple API for manipulating INI,
JSON, YAML, and TOML configuration files. For the time being, it only
supports INI and JSON.

Installation
------------

.. code:: bash

   $ pip install config-file

.. |Python Verison| image:: https://img.shields.io/pypi/pyversions/config-file.svg
.. |Version| image:: https://img.shields.io/pypi/v/config-file
   :target: https://pypi.org/project/config-file/
.. |Style| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://pypi.org/project/black/
.. |Documentation Status| image:: https://readthedocs.org/projects/config-file/badge/?version=latest
   :target: https://config-file.readthedocs.io/en/latest/?badge=latest
.. |Build Status| image:: https://travis-ci.com/eugenetriguba/config-file.svg?branch=master
   :target: https://travis-ci.com/eugenetriguba/config-file
.. |Codecov| image:: https://codecov.io/gh/eugenetriguba/config-file/graph/badge.svg
   :target: https://codecov.io/gh/eugenetriguba/config-file
